summaryrefslogtreecommitdiffstats
path: root/src/kde/kchmviewwindow_tdehtmlpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kde/kchmviewwindow_tdehtmlpart.h')
-rw-r--r--src/kde/kchmviewwindow_tdehtmlpart.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/kde/kchmviewwindow_tdehtmlpart.h b/src/kde/kchmviewwindow_tdehtmlpart.h
index b840b44..4bc45c7 100644
--- a/src/kde/kchmviewwindow_tdehtmlpart.h
+++ b/src/kde/kchmviewwindow_tdehtmlpart.h
@@ -19,8 +19,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#ifndef KCHMVIEWWINDOW_KHTMLPART_H
-#define KCHMVIEWWINDOW_KHTMLPART_H
+#ifndef KCHMVIEWWINDOW_TDEHTMLPART_H
+#define KCHMVIEWWINDOW_TDEHTMLPART_H
#include "kde-qt.h"
@@ -36,19 +36,19 @@
@author Georgy Yunaev
*/
/*
* For TQt-only version, we cannot compile KCHMViewWindow_KHTMLPart. However,
* we cannot just exclude it, because it would not generate a MOC file for a KDE
* version. Therefore we declare it, and compile the .moc file, but do not provide
* the class methods.
*/
#if defined (USE_KDE)
-class KCHMViewWindow_KHTMLPart : public KHTMLPart, public KCHMViewWindow
+class KCHMViewWindow_TDEHTMLPart : public TDEHTMLPart, public KCHMViewWindow
{
Q_OBJECT
public:
- KCHMViewWindow_KHTMLPart( TQTabWidget * parent );
- ~KCHMViewWindow_KHTMLPart();
+ KCHMViewWindow_TDEHTMLPart( TQTabWidget * parent );
+ ~KCHMViewWindow_TDEHTMLPart();
//! Open a page from current chm archive
virtual bool openPage (const TQString& url);
@@ -115,4 +115,4 @@ private:
#endif /* USE_KDE */
-#endif /* KCHMVIEWWINDOW_KHTMLPART_H */
+#endif /* KCHMVIEWWINDOW_TDEHTMLPART_H */
@@ -36,19 +36,19 @@
*/
/*
- * For TQt-only version, we cannot compile KCHMViewWindow_KHTMLPart. However,
+ * For TQt-only version, we cannot compile KCHMViewWindow_TDEHTMLPart. However,
* we cannot just exclude it, because it would not generate a MOC file for a KDE
* version. Therefore we declare it, and compile the .moc file, but do not provide